==> statpsych_1.7.0.tar.gz: statpsych/tests/testthat/_snaps/statpsych2.md <==
# ci.cor returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL        UL
          0.536 0.1018149 0.2978573 0.7058914

# ci.spcor returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL        UL
          0.582 0.1374298 0.2525662 0.7905182

# ci.cor2 returns valid matrix

    Code
      res
    Output
       Estimate         SE         LL        UL
          0.084 0.02967934 0.02803246 0.1463609

# ci.cor.dep returns valid matrix

    Code
      res
    Output
       Estimate        SE         LL       UL
          0.217 0.1026986 0.01323072 0.415802

# ci.cor2.gen returns valid matrix

    Code
      res
    Output
       Estimate   LL        UL
            0.2 0.07 0.3220656

# ci.pbcor returns valid matrix

    Code
      res
    Output
                   Estimate         SE        LL        UL
      Weighted:   0.7065799 0.04890959 0.5885458 0.7854471
      Unweighted: 0.7020871 0.05018596 0.5808366 0.7828948

# ci.spear returns valid matrix

    Code
      res
    Output
        Estimate         SE        LL        UL
       0.8699639 0.08241326 0.5840951 0.9638297

# ci.spear2 returns valid matrix

    Code
      res
    Output
       Estimate         SE         LL        UL
           0.06 0.08124926 -0.1003977 0.2185085

# ci.mape returns valid matrix

    Code
      res
    Output
       Estimate        SE       LL       UL
         2.3744 0.3314752 1.806022 3.121654

# ci.condslope returns valid matrix

    Code
      res
    Output
                        Estimate        SE        t  df           p        LL
      At low moderator    0.9328 0.4109570 2.269824 122 0.024973618 0.1192696
      At high moderator   1.7644 0.6070517 2.906507 122 0.004342076 0.5626805
                              UL
      At low moderator  1.746330
      At high moderator 2.966119

# ci.lc.reg returns valid matrix

    Code
      res
    Output
       Estimate        SE        t      df          p        LL       UL
          1.303 0.5085838 2.562016 78.8197 0.01231256 0.2906532 2.315347

# ci.fisher returns valid matrix

    Code
      res
    Output
           Estimate        LL        UL
      [1,]    0.641 0.5276396 0.7319293

# size.ci.slope returns valid numeric

    Code
      res
    Output
       Total sample size
                      83

# size.ci.cor returns valid numeric

    Code
      res
    Output
       Sample size
               188

# size.ci.spear returns valid numeric

    Code
      res
    Output
       Sample size
               200

# size.ci.pbcor returns valid numeric

    Code
      res
    Output
       Sample size
               168

---

    Code
      res
    Output
       Sample size
               168

# size.ci.rsqr returns valid numeric

    Code
      res
    Output
       Sample size
               226

# size.ci.condmean returns valid numeric

    Code
      res
    Output
       Total sample size
                     210

# size.ci.lc.ancova returns valid numeric

    Code
      res
    Output
       Sample size per group
                          21

# size.test.slope returns valid numeric

    Code
      res
    Output
       Total sample size
                     100

# size.test.cor returns valid numeric

    Code
      res
    Output
       Sample size
                48

# size.interval.cor returns valid numeric

    Code
      res
    Output
       Sample size
               360

# size.test.lc.ancova returns valid numeric

    Code
      res
    Output
       Sample size per group
                          46

# ci.rsqr returns valid matrix

    Code
      res
    Output
       R-squared adj R-squared         SE         LL        UL
           0.241     0.2206696 0.06752263 0.09819599 0.3628798

# ci.lc.gen.bs returns valid matrix

    Code
      res
    Output
       Estimate        SE       LL       UL
           1.63 0.2573806 1.125543 2.134457

# ci.lc.glm returns valid matrix

    Code
      res
    Output
       Estimate        SE       t df           p       LL       UL
       2.931111 0.4462518 6.56829  7 0.000313428 1.875893 3.986329

# ci.theil returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL   UL
            0.5 0.1085927 0.3243243 0.75

# power.cor returns valid matrix

    Code
      res
    Output
           Power
       0.7751947

# power.cor2 returns valid matrix

    Code
      res
    Output
           Power
       0.5919682

# size.test.cor2 returns valid matrix

    Code
      res
    Output
        n1  n2
       245 490

# size.test.cronbach2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                          77

# size.ci.cronbach2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         180

# size.ci.mape returns valid numeric

    Code
      res
    Output
       Sample size
                57

# size.ci.indirect returns valid matrix

    Code
      res
    Output
       Sample size
               106

# ci.ratio.mape2 returns valid matrix

    Code
      res
    Output
         MAPE1     MAPE2 MAPE1/MAPE2       LL       UL
       2.58087 0.8327273    3.099298 1.917003 5.010761

# ci.rel2 returns valid matrix

    Code
      res
    Output
       Estimate   LL        UL
            0.2 0.07 0.3220656

# ci.cronbach2 returns valid matrix

    Code
      res
    Output
       Estimate         LL       UL
           0.12 0.06973411 0.173236

# ci.bscor returns valid matrix

    Code
      res
    Output
        Estimate         SE        LL       UL
       0.8855666 0.06129908 0.7376327 0.984412

# pi.cor returns valid matrix

    Code
      res
    Output
              LL        UL
       0.6034092 0.8573224

# test.cor returns valid matrix

    Code
      res
    Output
       Estimate        z           p
          0.484 3.205432 0.001348601

# test.spear returns valid matrix

    Code
      res
    Output
       Estimate        z          p
          0.471 3.009628 0.00261568

# test.cor2 returns valid matrix

    Code
      res
    Output
       Estimate        z           p
          0.247 2.705709 0.006815877

# test.spear2 returns valid matrix

    Code
      res
    Output
       Estimate        z          p
          0.247 2.498645 0.01246691

# size.ci.cor2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         271

# size.ci.spear2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         314

# size.ci.cor.prior returns valid matrix

    Code
      res
    Output
       Sample size
               331

# adj.se returns valid matrix

    Code
      res
    Output
           Estimate   adj SE        t  df           p        LL        UL
      [1,]     3.78 1.738243 2.174609 114 0.031725582 0.3365531  7.223447
      [2,]     8.21 3.487559 2.354082 114 0.020279958 1.3011734 15.118827
      [3,]     2.99 1.087233 2.750102 114 0.006930554 0.8362007  5.143799

# fitindices returns valid matrix

    Code
      res
    Output
             NFI   adj NFI       CFI       TLI      RMSEA
       0.9450141 0.9837093 0.9823428 0.9646857 0.03746109

# size.ci.biphi example

    Code
      res
    Output
       Sample size
               195

# size.ci.ancova2 example

    Code
      res
    Output
       n1 n2
       16 32

# size.ci.slope.gen example

    Code
      res
    Output
       Sample size
               305

# size.test.ancova2 example

    Code
      res
    Output
       n1 n2
       47 94

# size.test.slope.gen example

    Code
      res
    Output
       Sample size
               156

# signal example

    Code
      res
    Output
              HR      FAR  d-prime  Threshold       Bias
       0.8168317 0.460396 1.002793 0.09943603 -0.4019603

# expon.slope example

    Code
      res
    Output
                        Estimate        LL       UL
      exp(B)            1.652022  1.528651  1.78535
      100[exp(B) - 1]% 65.202201 52.865066 78.53502

# ci.bayes.cor example

    Code
      res
    Output
       Posterior mean         LL        UL
            0.1873765 0.02795441 0.3375031

# ci.bayes.spcor example

    Code
      res
    Output
       Posterior mean         LL        UL
            0.2272797 0.07288039 0.3710398

==> statpsych_1.8.0.tar.gz: statpsych/tests/testthat/_snaps/statpsych2.md <==
# ci.cor returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL        UL
          0.536 0.1018149 0.2978573 0.7058914

# ci.spcor returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL        UL
          0.582 0.1374298 0.2525662 0.7905182

# ci.cor2 returns valid matrix

    Code
      res
    Output
       Estimate         SE         LL        UL
          0.084 0.02967934 0.02803246 0.1463609

# ci.cor.dep returns valid matrix

    Code
      res
    Output
       Estimate        SE         LL       UL
          0.217 0.1026986 0.01323072 0.415802

# ci.cor2.gen returns valid matrix

    Code
      res
    Output
       Estimate   LL        UL
            0.2 0.07 0.3220656

# ci.pbcor returns valid matrix

    Code
      res
    Output
                   Estimate         SE        LL        UL
      Weighted:   0.7065799 0.04890959 0.5885458 0.7854471
      Unweighted: 0.7020871 0.05018596 0.5808366 0.7828948

# ci.spear returns valid matrix

    Code
      res
    Output
        Estimate         SE        LL        UL
       0.8699639 0.08241326 0.5840951 0.9638297

# ci.spear2 returns valid matrix

    Code
      res
    Output
       Estimate         SE         LL        UL
           0.06 0.08124926 -0.1003977 0.2185085

# ci.mape returns valid matrix

    Code
      res
    Output
       Estimate        SE       LL       UL
         2.3744 0.3314752 1.806022 3.121654

# ci.condslope returns valid matrix

    Code
      res
    Output
                        Estimate        SE        t  df           p        LL
      At low moderator    0.9328 0.4109570 2.269824 122 0.024973618 0.1192696
      At high moderator   1.7644 0.6070517 2.906507 122 0.004342076 0.5626805
                              UL
      At low moderator  1.746330
      At high moderator 2.966119

# ci.lc.reg returns valid matrix

    Code
      res
    Output
       Estimate        SE        t      df          p        LL       UL
          1.303 0.5085838 2.562016 78.8197 0.01231256 0.2906532 2.315347

# ci.fisher returns valid matrix

    Code
      res
    Output
           Estimate        LL        UL
      [1,]    0.641 0.5276396 0.7319293

# size.ci.slope returns valid numeric

    Code
      res
    Output
       Total sample size
                      83

# size.ci.cor returns valid numeric

    Code
      res
    Output
       Sample size
               188

# size.ci.spear returns valid numeric

    Code
      res
    Output
       Sample size
               200

# size.ci.pbcor returns valid numeric

    Code
      res
    Output
       Sample size
               168

---

    Code
      res
    Output
       Sample size
               168

# size.ci.rsqr returns valid numeric

    Code
      res
    Output
       Sample size
               226

# size.ci.condmean returns valid numeric

    Code
      res
    Output
       Total sample size
                     210

# size.ci.lc.ancova returns valid numeric

    Code
      res
    Output
       Sample size per group
                          21

# size.test.slope returns valid numeric

    Code
      res
    Output
       Total sample size
                     100

# size.test.cor returns valid numeric

    Code
      res
    Output
       Sample size
                48

# size.interval.cor returns valid numeric

    Code
      res
    Output
       Sample size
               360

# size.test.lc.ancova returns valid numeric

    Code
      res
    Output
       Sample size per group
                          46

# ci.rsqr returns valid matrix

    Code
      res
    Output
       R-squared adj R-squared         SE         LL        UL
           0.241     0.2206696 0.06752263 0.09819599 0.3628798

# ci.lc.gen.bs returns valid matrix

    Code
      res
    Output
       Estimate        SE       LL       UL
           1.63 0.2573806 1.125543 2.134457

# ci.lc.glm returns valid matrix

    Code
      res
    Output
       Estimate        SE       t df           p       LL       UL
       2.931111 0.4462518 6.56829  7 0.000313428 1.875893 3.986329

# ci.theil returns valid matrix

    Code
      res
    Output
       Estimate        SE        LL   UL
            0.5 0.1085927 0.3243243 0.75

# power.cor returns valid matrix

    Code
      res
    Output
           Power
       0.7751947

# power.cor2 returns valid matrix

    Code
      res
    Output
           Power
       0.5919682

# size.test.cor2 returns valid matrix

    Code
      res
    Output
        n1  n2
       245 490

# size.test.cronbach2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                          77

# size.ci.cronbach2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         180

# size.ci.mape returns valid numeric

    Code
      res
    Output
       Sample size
                57

# size.ci.indirect returns valid matrix

    Code
      res
    Output
       Sample size
               106

# ci.ratio.mape2 returns valid matrix

    Code
      res
    Output
         MAPE1     MAPE2 MAPE1/MAPE2       LL       UL
       2.58087 0.8327273    3.099298 1.917003 5.010761

# ci.rel2 returns valid matrix

    Code
      res
    Output
       Estimate   LL        UL
            0.2 0.07 0.3220656

# ci.cronbach2 returns valid matrix

    Code
      res
    Output
       Estimate         LL       UL
           0.12 0.06973411 0.173236

# ci.bscor returns valid matrix

    Code
      res
    Output
        Estimate         SE        LL       UL
       0.8855666 0.06129908 0.7376327 0.984412

# pi.cor returns valid matrix

    Code
      res
    Output
              LL        UL
       0.6034092 0.8573224

# test.cor returns valid matrix

    Code
      res
    Output
       Estimate        z           p
          0.484 3.205432 0.001348601

# test.spear returns valid matrix

    Code
      res
    Output
       Estimate        z          p
          0.471 3.009628 0.00261568

# test.cor2 returns valid matrix

    Code
      res
    Output
       Estimate        z           p
          0.247 2.705709 0.006815877

# test.spear2 returns valid matrix

    Code
      res
    Output
       Estimate        z          p
          0.247 2.498645 0.01246691

# size.ci.cor2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         271

# size.ci.spear2 returns valid matrix

    Code
      res
    Output
       Sample size per group
                         314

# size.ci.cor.prior returns valid matrix

    Code
      res
    Output
       Sample size
               331

# adj.se returns valid matrix

    Code
      res
    Output
           Estimate   adj SE        t  df           p        LL        UL
      [1,]     3.78 1.738243 2.174609 114 0.031725582 0.3365531  7.223447
      [2,]     8.21 3.487559 2.354082 114 0.020279958 1.3011734 15.118827
      [3,]     2.99 1.087233 2.750102 114 0.006930554 0.8362007  5.143799

# fitindices returns valid matrix

    Code
      res
    Output
             NFI   adj NFI       CFI       TLI      RMSEA
       0.9450141 0.9837093 0.9823428 0.9646857 0.03746109

# size.ci.biphi example

    Code
      res
    Output
       Sample size
               195

# size.ci.ancova2 example

    Code
      res
    Output
       n1 n2
       16 32

# size.ci.slope.gen example

    Code
      res
    Output
       Sample size
               305

# size.test.ancova2 example

    Code
      res
    Output
       n1 n2
       47 94

# size.test.slope.gen example

    Code
      res
    Output
       Sample size
               156

# signal example

    Code
      res
    Output
              HR      FAR  d-prime  Threshold       Bias
       0.8168317 0.460396 1.002793 0.09943603 -0.4019603

# expon.slope example

    Code
      res
    Output
                        Estimate        LL       UL
      exp(B)            1.652022  1.528651  1.78535
      100[exp(B) - 1]% 65.202201 52.865066 78.53502

# ci.bayes.cor example

    Code
      res
    Output
       Posterior mean         LL        UL
            0.1873765 0.02795441 0.3375031

# ci.bayes.spcor example

    Code
      res
    Output
       Posterior mean         LL        UL
            0.2272797 0.07288039 0.3710398

# test.mono.median.bs example

    Code
      res
    Output
           Estimate       SE        LL         UL
       1 2   -11.71 4.130690 -21.59879 -1.8212115
       2 3   -11.72 4.780481 -23.16438 -0.2756247
       3 4   -16.92 5.382128 -29.80471 -4.0352947

# ci.slope.median.bs example

    Code
      res
    Output
        Estimate        SE        z           p        LL        UL
       0.3664407 0.1163593 3.149216 0.001637091 0.1383806 0.5945008

# size.ci.gen example

    Code
      res
    Output
       Sample size
                61

# size.ci.gen2 example

    Code
      res
    Output
       n1 n2
       45 45

# size.test.gen(.05, .8, 2.89, 30, 5) example

    Code
      res
    Output
       Sample size
                79

# size.test.gen2(.05, .85, .175, 30, .5, 1) example

    Code
      res
    Output
       n1 n2
       66 66
